//muroar.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009
 *
 *  This file is part of µRoar,
 *  a minimum library to access a RoarAudio Sound Server.
 *
 *  µRoar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  µRoar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with µRoar.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _MUROAR_H_
#define _MUROAR_H_

#ifdef __cplusplus
extern "C" {
#endif

// types:
#include <unistd.h>

#define MUROAR_PORT         16002

#define MUROAR_CMD_IDENTIFY        1
#define MUROAR_CMD_AUTH            2
#define MUROAR_CMD_NEW_STREAM      3
#define MUROAR_CMD_EXEC_STREAM     5
#define MUROAR_CMD_QUIT            6
#define MUROAR_CMD_BEEP           24

#define MUROAR_PLAY_WAVE           1
#define MUROAR_PLAY_MIDI          12
#define MUROAR_PLAY_LIGHT         14
#define MUROAR_MONITOR_WAVE        3
#define MUROAR_MONITOR_MIDI       13
#define MUROAR_MONITOR_LIGHT      15

#define MUROAR_CODEC_PCM_S_LE   0x01
#define MUROAR_CODEC_PCM_S_BE   0x02
#define MUROAR_CODEC_PCM_S_PDP  0x03
#define MUROAR_CODEC_PCM_U_LE   0x05
#define MUROAR_CODEC_PCM_U_BE   0x06
#define MUROAR_CODEC_PCM_U_PDP  0x07
#define MUROAR_CODEC_MIDI       0x60
#define MUROAR_CODEC_DMX512     0x70
#define MUROAR_CODEC_ROARDMX    0x71

#ifdef __WIN32
#define MUROAR_CODEC_PCM_S      MUROAR_CODEC_PCM_S_LE
#define MUROAR_CODEC_PCM_U      MUROAR_CODEC_PCM_U_LE
#else

#if BYTE_ORDER == BIG_ENDIAN
#define MUROAR_CODEC_PCM_S      MUROAR_CODEC_PCM_S_BE
#define MUROAR_CODEC_PCM_U      MUROAR_CODEC_PCM_U_BE
#elif BYTE_ORDER == LITTLE_ENDIAN
#define MUROAR_CODEC_PCM_S      MUROAR_CODEC_PCM_S_LE
#define MUROAR_CODEC_PCM_U      MUROAR_CODEC_PCM_U_LE
#else
// most likely a PDP
#define MUROAR_CODEC_PCM_S      MUROAR_CODEC_PCM_S_PDP
#define MUROAR_CODEC_PCM_U      MUROAR_CODEC_PCM_U_PDP
#endif

#endif

#define MUROAR_CODEC_PCM        MUROAR_CODEC_PCM_S

// muroar.c:
int muroar_connect(char * server, char * name);
int muroar_close  (int fh);
int muroar_quit   (int fh);
int muroar_beep   (int fh);
int muroar_stream (int fh, int dir, int * stream, int codec, int rate, int channels, int bits);

// muroario.c:
ssize_t muroar_write  (int fh, const void * buf, size_t len);
ssize_t muroar_read   (int fh,       void * buf, size_t len);

#ifdef __cplusplus
}
#endif

#endif

//ll
